"use strict";
this.name        = "cargoSpotter_worldScript.js";
this.author      = "Thargoid";
this.copyright   = "CC BY-NC-SA 3.0";
this.description = "Script for Cargo Spotter";
this.version     = "1.1";

//
// Event Handlers
//

//-----------------------------------------------------------------------------------//
this.startUp = this.shipLaunchedFromStation = this.shipExitedWitchspace = function _cspotter_start() { 
    if (player.ship.equipmentStatus("EQ_CARGOSPOTTER") === "EQUIPMENT_OK") {
        missionVariables.cargoSpotter = "ACTIVE"; 
        this.$startTimer();
    } else 
        missionVariables.cargoSpotter = "INACTIVE";
}

//-----------------------------------------------------------------------------------//
this.shipDied = this.shipDockedWithStation = this.shipWillEnterWitchspace = this.$stopTimer = function _cspotter_stopTimer() {
    missionVariables.cargoSpotter = "INACTIVE";
    if (this.scanTimer && this.scanTimer.isRunning) {
        this.scanTimer.stop();  
        delete this.scanTimer;
    }
}

//-----------------------------------------------------------------------------------//
this.equipmentDamaged = function _cspotter_equipmentDamaged(equipment) {
    if(equipment === "EQ_CARGOSPOTTER")  { 
        missionVariables.cargoSpotter = "INACTIVE";
        this.$stopTimer(); 
    }
}    

//
// Internal functions
//

//-----------------------------------------------------------------------------------//
this.$startTimer = function _cspotter_startTimer() { 
    if (!this.scanTimer)
        this.scanTimer = new Timer(this, this.$findCargo, 0, 1)
    else
        this.scanTimer.start();
}
    
//-----------------------------------------------------------------------------------//
this.$findCargo = function _cspotter_findCargo() { // cargo pods, alloys, boulders/splinters && uncontrolled thargons
    function _cspotter_targetCargo(entity) { 
        return (    entity.isShip && 
                    (entity.isCargo || entity.isBoulder || (entity.hasRole("thargon") && entity.AI === "dumbAI.plist") ) && 
                    entity.isInSpace && !entity.hasOwnProperty("$cargoSpotter_tagged")); 
    }

    var cargoArray = system.filteredEntities(this, _cspotter_targetCargo, player.ship, 25600); 
    if (cargoArray.length === 0) return;
    
    var i = cargoArray.length;
    var c;
    while (i--) {
        c = cargoArray[i];
        c.$cargoSpotter_tagged = true;
        this.glowKey = "cargoSpotter_blueGlow"; // default highlight glow for cargopods & alloys
        if (c.hasRole("thargon")) this.glowKey = "cargoSpotter_greenGlow";  // highlight inactive thargons in green
        if (c.isBoulder || c.hasRole("splinter")) this.glowKey = "cargoSpotter_grayGlow";  // highlight rocks in grey
        if (c.hasRole("escape-capsule")) this.glowKey = "cargoSpotter_redGlow";  // highlight escape pods in red            
        this.glow = system.addVisualEffect(this.glowKey, c.position);
        this.glow.$cargoSpotter_cargoEntity = c;
    }
}
